spannertools.TextSpanner
========================

.. abjad-lineage:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner

.. autoclass:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.leaves
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.override
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.set
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.start_offset
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.storage_format
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.timespan
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.written_duration
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.append
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.clear
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.index
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.pop_left
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.__call__
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.__ge__
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.__gt__
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.__le__
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner.__repr__
   :noindex:
